# Generated by Django 2.1.7 on 2019-07-22 07:51

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0012_auto_20190423_1552'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='mobile_content',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='모바일 페이지 내용'),
        ),
        migrations.AddField(
            model_name='page',
            name='mobile_style',
            field=models.TextField(blank=True, default='', null=True, verbose_name='CSS'),
        ),
        migrations.AddField(
            model_name='page',
            name='template',
            field=models.CharField(blank=True, default='', max_length=256, null=True, verbose_name='커스텀 템플릿'),
        ),
        migrations.AlterField(
            model_name='page',
            name='content',
            field=ckeditor_uploader.fields.RichTextUploadingField(verbose_name='PC 페이지 내용'),
        ),
        migrations.AlterField(
            model_name='page',
            name='style',
            field=models.TextField(blank=True, default='', null=True, verbose_name='CSS'),
        ),
        migrations.AlterField(
            model_name='post',
            name='cate',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='page.PostCategory'),
        ),
    ]
